@@ -1,12 +1,13 @@
 "use strict";
-const hasToStringTag = require("has-to-string-tag-x");
+const {default:hasToStringTag} = require("has-to-string-tag-x");
 const isObject = require("is-object");
 const isURLSearchParams = require("is-urlsearchparams");
-const {lenientProperties, strictProperties} = require("./props");
+const {LENIENT_PROPERTIES, STRICT_PROPERTIES} = require("./props");
+
+const SEARCH_PARAMS = "searchParams";
+const URL_CLASS = "[object URL]";
 
-const searchParams = "searchParams";
 const toStringTag = Object.prototype.toString;
-const urlClass = "[object URL]";
 
 
 
@@ -16,16 +17,16 @@ const isURL = (url, supportIncomplete=false) =>
 	{
 		return false;
 	}
-	else if (hasToStringTag && toStringTag.call(url)!==urlClass)
+	else if (hasToStringTag && toStringTag.call(url)!==URL_CLASS)
 	{
 		// Shimmed implementation with incorrect constructor name
 		return false;
 	}
-	else if (!strictProperties.every(prop => prop in url))
+	else if (!STRICT_PROPERTIES.every(prop => prop in url))
 	{
 		return false;
 	}
-	else if (supportIncomplete && searchParams in url)
+	else if (supportIncomplete && SEARCH_PARAMS in url)
 	{
 		return isURLSearchParams.lenient(url.searchParams);
 	}
@@ -33,7 +34,7 @@ const isURL = (url, supportIncomplete=false) =>
 	{
 		return true;
 	}
-	else if (lenientProperties.every(prop => prop in url))
+	else if (LENIENT_PROPERTIES.every(prop => prop in url))
 	{
 		return isURLSearchParams(url.searchParams);
 	}
@@ -49,4 +50,4 @@ isURL.lenient = url => isURL(url, true);
 
 
 
-module.exports = isURL;
+module.exports = Object.freeze(isURL);
