@@ -1,13 +1,13 @@
 "use strict";
 
-const lenientProperties =
+const LENIENT_PROPERTIES =
 [
 	"origin",
 	"searchParams",
 	"toJSON"
 ];
 
-const strictProperties =
+const STRICT_PROPERTIES =
 [
 	"hash",
 	"host",
@@ -24,4 +24,4 @@ const strictProperties =
 
 
 
-module.exports = { lenientProperties, strictProperties };
+module.exports = { LENIENT_PROPERTIES, STRICT_PROPERTIES };
